Compute the border vertices for each region in an annot.
Source:R/helpers.R
annot.outline.border.vertices.RdCompute the border vertices for each region in an annot.
Usage
annot.outline.border.vertices(
annotdata,
surface_mesh,
silent = TRUE,
expand_inwards = 0L,
limit_to_regions = NULL
)Arguments
- annotdata
an annotation, as returned by functions like
subject.annot. If a character string, interpreted as a path to a file containing such data, and loaded withfreesurferformats::read.fs.annot- surface_mesh
brain surface mesh, as returned by functions like
subject.surfaceorread.fs.surface. If a character string, interpreted as a path to a file containing such data, and loaded withfreesurferformats::read.fs.surface- silent
logical, whether to suppress status messages.
- expand_inwards
integer, additional thickness of the borders. Increases computation time, defaults to 0L.
- limit_to_regions
vector of character strings or NULL, a list of regions for which to draw the outline (see
get.atlas.region.names). If NULL, all regions will be used. If (and only if) this parameter is used, the 'outline_color' parameter can be a vector of color strings, one color per region.