apply.labeldata.to.morphdata: Apply a label to morphometry data.

View source: R/fsdir_abstraction_subject.R

apply.labeldata.to.morphdataR Documentation

Apply a label to morphometry data.

Description

This function will set all values in morphdata which are not part of the labeldata to NA (or whatever is specified by 'masked_data_value'). This is typically used to ignore values which are not part of the cortex (or any other label) during your analysis.

Usage

apply.labeldata.to.morphdata(morphdata, labeldata, masked_data_value = NA)

Arguments

morphdata

numerical vector, the morphometry data for one hemisphere

labeldata

integer vector or fs.label instance. A label as returned by subject.label.

masked_data_value

numerical, the value to set for all morphometry data values of vertices which are not part of the label. Defaults to NA.

Value

numerical vector, the masked data.

See Also

Other label functions: apply.label.to.morphdata(), subject.lobes(), subject.mask(), vis.labeldata.on.subject(), vis.subject.label()

Other morphometry data functions: apply.label.to.morphdata(), group.morph.native(), group.morph.standard(), subject.morph.native(), subject.morph.standard()


fsbrain documentation built on Aug. 23, 2026, 5:06 p.m.