as.tract.bundle.list: Turn the various supported tract inputs into a list of...

View source: R/tracts.R

as.tract.bundle.listR Documentation

Turn the various supported tract inputs into a list of bundles.

Description

Turn the various supported tract inputs into a list of bundles.

Usage

as.tract.bundle.list(
  tracts,
  coords = "ras",
  transform_matrix = NULL,
  max_tracks = Inf,
  skip_tracks = 0L,
  bbox = NULL,
  silent = FALSE
)

Arguments

tracts

see vis.tracts.

coords, transform_matrix, max_tracks, skip_tracks, bbox, silent

parameters passed on to read.tract.bundles if tracts is a file path or directory.

Value

named list of fs.tracts instances.


fsbrain documentation built on Sept. 27, 2026, 1:07 a.m.