check.segment.points: Check whether a matrix is a valid point matrix for...

View source: R/coloredpaths.R

check.segment.pointsR Documentation

Check whether a matrix is a valid point matrix for coloredpaths.

Description

Check whether a matrix is a valid point matrix for coloredpaths.

Usage

check.segment.points(x, arg_name)

Arguments

x

the object to check.

arg_name

character string, the name of the parameter, used in error messages.

Value

an (n, 3) numeric matrix.


fsbrain documentation built on Sept. 27, 2026, 1:07 a.m.