Return the standard fsbrain diverging colormap.
Arguments
- report
logical, whether to print a message with a name of the chosen colormap, in format package::function#palette.
Note
Returns some diverging palette, suitable for visualizing data that is centered around zero.