Return the standard fsbrain qualitative colormap.
Arguments
- report
logical, whether to print a message with a name of the chosen colormap, in format package::function#palette.
Note
Returns some qualitative palette, suitable for visualizing categorical data.