Compute atlas or annotation surface color layer.
Source:R/vis_surface_background.R
collayer.bg.atlas.RdCompute atlas or annotation surface color layer.
Usage
collayer.bg.atlas(
subjects_dir,
subject_id,
hemi = "both",
atlas = "aparc",
grayscale = FALSE,
outline = FALSE,
outline_surface = "white"
)Arguments
- subjects_dir
character string, the FreeSurfer SUBJECTS_DIR.
- subject_id
character string, the subject identifier.
- hemi
character string, one of 'lh', 'rh', or 'both'. The latter will merge the data for both hemis into a single vector.
- atlas
character string, the atlas name. E.g., "aparc", "aparc.2009s", or "aparc.DKTatlas". Used to construct the name of the annotation file to be loaded.
- grayscale
logical, whether to convert the atlas colors to grayscale
- outline
logical, whether to draw an outline only instead of filling the regions. Defaults to
FALSE. Instead of passingTRUE, one can also pass a list of extra parameters to pass toannot.outline, e.g.,outline=list('outline_color'='#000000').- outline_surface
character string, the surface to load. Only relevant when 'outline' is used. (In that case the surface mesh is needed to compute the vertices forming the region borders.)
See also
You can plot the return value using vis.color.on.subject.
Other surface color layer:
collayer.bg(),
collayer.bg.meancurv(),
collayer.bg.sulc(),
collayer.from.annot(),
collayer.from.annotdata(),
collayer.from.mask.data(),
collayer.from.morphlike.data(),
collayers.merge()