Compute binarized mean curvature surface color layer.
Source:R/vis_surface_background.R
collayer.bg.meancurv.RdCompute a binarized mean curvature surface color layer, this is intended as a background color layer. You can merge it with your data layer using collayers.merge.
Arguments
- subjects_dir
character string, the FreeSurfer SUBJECTS_DIR.
- subject_id
character string, the subject identifier.
- hemi
character string, one of 'lh', 'rh', or 'both'. The latter will merge the data for both hemis into a single vector.
- cortex_only
logical, whether to restrict pattern computation to the cortex.
- bin_colors
vector of two character strings, the two colors to use.
- bin_thresholds
vector of 1 or 2 double values, the curvature threshold values used to separate gyri from sulci.
See also
You can plot the return value using vis.color.on.subject.
Other surface color layer:
collayer.bg(),
collayer.bg.atlas(),
collayer.bg.sulc(),
collayer.from.annot(),
collayer.from.annotdata(),
collayer.from.mask.data(),
collayer.from.morphlike.data(),
collayers.merge()