Compute surface color layer from annotation or atlas data.
Source:R/vis_surface_background.R
collayer.from.annot.RdCompute surface color layer from annotation or atlas data.
Arguments
- subjects_dir
character string, the FreeSurfer SUBJECTS_DIR.
- subject_id
character string, the subject identifier.
- hemi
character string, one of 'lh', 'rh', or 'both'.
- atlas
character string, the atlas name. E.g., "aparc", "aparc.2009s", or "aparc.DKTatlas". Used to construct the name of the annotation file to be loaded.
Value
named hemi list, each entry is a vector of color strings, one color per surface vertex. The coloring represents the atlas data.
See also
You can plot the return value using vis.color.on.subject.
Other surface color layer:
collayer.bg(),
collayer.bg.atlas(),
collayer.bg.meancurv(),
collayer.bg.sulc(),
collayer.from.annotdata(),
collayer.from.mask.data(),
collayer.from.morphlike.data(),
collayers.merge()