coloredmesh_to_scimesh: Convert a single fs.coloredmesh to a scimesh mesh descriptor

View source: R/scimesh_bridge.R

coloredmesh_to_scimeshR Documentation

Convert a single fs.coloredmesh to a scimesh mesh descriptor

Description

Convert a single fs.coloredmesh to a scimesh mesh descriptor

Usage

coloredmesh_to_scimesh(cmesh, style = "default")

Arguments

cmesh

an fs.coloredmesh instance.

style

a rendering style: a style name, a named list of style parameters, or 'from_mesh' (use cmesh$style). Only the alpha value is consumed here (per-mesh vertex alpha).

Value

a scimesh mesh descriptor list with vertices, triangles, and colors.


fsbrain documentation built on Aug. 23, 2026, 5:06 p.m.