Check for the given color strings whether they represent gray scale colors.
Source:R/helpers.R
colors.are.grayscale.RdCheck for the given color strings whether they represent gray scale colors.
R/helpers.R
colors.are.grayscale.RdCheck for the given color strings whether they represent gray scale colors.