Vectorized version of cube3D.tris
Arguments
- centers
numerical matrix with 3 columns. Each column represents the x, y, z coordinates of a center at which to create a cube.
- edge_length
numerical vector or scalar, the edge length. Must have length 1 (same edge length for all cubes), or the length must be identical to the number of rows in parameter
centers.
Value
matrix of triangle coordinates, see cube3D.tris.
Examples
# Plot a 3D cloud of 20000 voxels:
centers = matrix(rnorm(20000*3)*100, ncol=3);
rgl::triangles3d(cubes3D.tris(centers));
3D plot