filter_scene_by_view: Filter a scimesh scene to the meshes visible from a given...

View source: R/scimesh_bridge.R

filter_scene_by_viewR Documentation

Filter a scimesh scene to the meshes visible from a given view

Description

Filter a scimesh scene to the meshes visible from a given view

Usage

filter_scene_by_view(scene, hemi_filter)

Arguments

scene

a named list of scimesh mesh descriptors (with "lh" and/or "rh" entries).

hemi_filter

character string, one of "lh", "rh", or "both".

Value

a flat list of scimesh mesh descriptors for the given view.


fsbrain documentation built on Aug. 23, 2026, 5:06 p.m.