Change data to ensure requested data_range.
force.to.range(x, data_range, allow_append = FALSE)Modified version of x. The data will be clamped and / or at most 2 values may be appended to x.
numerical vector, the input data.
numerical vector of length 2, the range into which to force the data values in 'x'. If NULL, the input data in 'x' is returned as is.
logical, whether to allow adding of more extreme data values. Allows a range larger than the data range. If set to TRUE, you will have to remove the extra values from the colors after generation of the colormap.