fs.coloredmesh constructor
Arguments
- mesh
a
mesh3dinstance as returned bytmesh3dor anfs.surfacebrain surface mesh as returned by functions likesubject.surface.- col
vector of vertex colors for the mesh, one color per vertex. Expanded if exactly one color.
- hemi
character string, one of 'lh' or 'rh'. This may be used by visualization functions to decide whether or not to show this mesh in a certain view.
- render
logical, whether to render this mesh during visualization
- metadata
optional, named list containing metadata
- add_normals
logical, whether to compute normals and save them in the mesh.