Turn surface mesh into a igraph and return its adjacency list representation.
Source:R/brain_igraph.R
fs.surface.as.adjacencylist.RdTurn surface mesh into a igraph and return its adjacency list representation.
R/brain_igraph.R
fs.surface.as.adjacencylist.RdTurn surface mesh into a igraph and return its adjacency list representation.