Create igraph undirected graph from a brain surface mesh.
Source:R/brain_igraph.R
fs.surface.to.igraph.RdCreate igraph undirected graph from a brain surface mesh.
Examples
if (FALSE) { # \dontrun{
# Find the one-ring neighbors of vertex 15 on the fsaverage left hemi:
sf = subject.surface(fsaverage.path(T), "fsaverage", "white", "lh");
g = fs.surface.to.igraph(sf);
igraph::neighborhood(g, order = 1, nodes = 15);
} # }