| fsbrain.renderable | R Documentation |
Check whether object can be rendered by fsbrain
fsbrain.renderable(x)
x |
any |
TRUE if x is an instance of a class that can be rendered by fsbrain visualization functions, and FALSE otherwise. Currently, the following types are renderable: fs.coloredvoxels, fs.coloredmesh, Triangles3D.
is.Triangles3D
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.