get.rglstyle: Get the default visualization style parameters as a named...

View source: R/vis_meshes.R

get.rglstyleR Documentation

Get the default visualization style parameters as a named list.

Description

Run material3d without arguments to see valid style keywords to create new styles.

Usage

get.rglstyle(style)

Arguments

style

string. A style name. Available styles are one of: "default", "shiny", "semitransparent", "glass", "edges".

Value

a style, resolved to a parameter list compatible with material3d.

Note

In addition to the style names listed above, the magic word 'from_mesh' can be passed as parameter 'style' to the rendering functions: it makes them use the style stored in the 'style' field of each individual mesh (see coloredmesh.from.color). This allows you to give individual meshes of a scene their own look, e.g., to render a cortex mesh semi-transparently behind colored data meshes, see vis.subcortical.region.values. Note that the scimesh renderer backend currently only supports the alpha channel of a style, not other material properties.

See Also

shade3d can use the returned style


fsbrain documentation built on Sept. 27, 2026, 1:07 a.m.