Learn R Programming

fsbrain (version 0.6.0)

getIn: Retrieve values from nested named lists

Description

Retrieve values from nested named lists

Usage

getIn(named_list, listkeys, default = NULL)

Value

the value at the path through the lists, or NULL (or the 'default') if no such path exists.

Arguments

named_list

a named list

listkeys

vector of character strings, the nested names of the lists

default

the default value to return in case the requested value is NULL.

Examples

Run this code
   data = list("regions"=list("frontal"=list("thickness"=2.3, "area"=2345)));
   getIn(data, c("regions", "frontal", "thickness"));       # 2.3
   getIn(data, c("regions", "frontal", "nosuchentry"));     # NULL
   getIn(data, c("regions", "nosuchregion", "thickness"));  # NULL
   getIn(data, c("regions", "nosuchregion", "thickness"), default=14);  # 14

Run the code above in your browser using DataLab