Access a single file from the package cache by its file name.
Source:R/optdata.R
get_optional_data_filepath.RdAccess a single file from the package cache by its file name.
R/optdata.R
get_optional_data_filepath.RdAccess a single file from the package cache by its file name.