| group.morph.agg.standard.vertex | R Documentation |
Aggregate vertex-wise values over subjects, leading to one aggregated measure per vertex.
group.morph.agg.standard.vertex(
subjects_dir,
subjects_list,
measure,
hemi,
fwhm,
agg_fun = mean,
template_subject = "fsaverage",
format = "mgh",
cortex_only = FALSE,
agg_fun_extra_params = NULL,
split_by_hemi = FALSE
)
subjects_dir |
string. The FreeSurfer SUBJECTS_DIR, i.e., a directory containing the data for all your subjects, each in a subdir named after the subject identifier. |
subjects_list |
string vector. A vector of subject identifiers that match the directory names within subjects_dir. |
measure |
string. Name of the vertex-wise measure of morphometry data file. E.g., "area" or "thickness". Used to construct the name of the morphometry file to be loaded. |
hemi |
string, one of 'lh', 'rh' or 'both'. The hemisphere name. Used to construct the names of the annotation and morphometry data files to be loaded. |
fwhm |
string. Smoothing as string, e.g. '10' or '25'. |
agg_fun |
function. An R function that aggregates data, typically |
template_subject |
string. Template subject name, defaults to 'fsaverage'. |
format |
string. One of 'mgh', 'mgz', 'curv'. Defaults to 'mgh'. |
cortex_only |
logical, whether to mask the medial wall, i.e., whether the morphometry data for all vertices which are not part of the cortex (as defined by the label file |
agg_fun_extra_params |
named list, extra parameters to pass to the aggregation function 'agg_fun' besides the loaded morphometry data. This is useful if you have masked the data and need to ignore NA values in the agg_fun. |
split_by_hemi |
logical, whether to return a hemilist |
Other aggregation functions:
group.agg.atlas.native(),
group.agg.atlas.standard(),
subject.atlas.agg()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.