| group.multimorph.agg.native | R Documentation |
Compute the mean (or other aggregates) over all vertices of a subject from native space morphometry data (like 'surf/lh.area'). You can specify several measures and hemispheres. Uses knowledge about the FreeSurfer directory structure to load the correct files.
group.multimorph.agg.native(
subjects_dir,
subjects_list,
measures,
hemis,
agg_fun = mean,
format = "curv",
cast = TRUE,
cortex_only = FALSE,
agg_fun_extra_params = NULL
)
subjects_dir |
string. The FreeSurfer SUBJECTS_DIR, i.e., a directory containing the data for all your subjects, each in a subdir named after the subject identifier. |
subjects_list |
string vector. A vector of subject identifiers that match the directory names within subjects_dir. |
measures |
vector of strings. Names of the vertex-wise morphometry measures. E.g., c("area", "thickness"). Used to construct the names of the morphometry file to be loaded. |
hemis |
string, one of 'lh', 'rh' or 'both'. The hemisphere name. Used to construct the names of the annotation and morphometry data files to be loaded. |
agg_fun |
function. An R function that aggregates data, typically |
format |
string. One of 'mgh', 'mgz', 'curv'. Defaults to 'mgh'. |
cast |
Whether a separate 'hemi' column should exist. |
cortex_only |
logical, whether to mask the medial wall, i.e., whether the morphometry data for all vertices which are not part of the cortex (as defined by the label file |
agg_fun_extra_params |
named list, extra parameters to pass to the aggregation function 'agg_fun' besides the loaded morphometry data. This is useful if you have masked the data and need to ignore NA values in the agg_fun. |
dataframe with aggregated values over all measures and hemis for all subjects, with m columns and n rows, where n is the number of subjects. The m columns are 'subject_id' and '<hemi>.<measure>' (e.g., "lh.thickness") for all combinations of hemi and measure, the latter contains the aggregated data.
Other global aggregation functions:
group.morph.agg.native(),
group.morph.agg.standard(),
group.multimorph.agg.standard()
## Not run:
subjects_dir = fsbrain::get_optional_data_filepath("subjects_dir");
subjects_list = c("subject1", "subject2")
data = group.multimorph.agg.native(subjects_dir, subjects_list, c("thickness", "area"),
c("lh", "rh"), cast=FALSE, cortex_only=TRUE, agg_fun=mean,
agg_fun_extra_params=list("na.rm"=TRUE));
head(data);
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.