group.start.rows: Compute the first row of every group in a concatenated...

View source: R/tracts.R

group.start.rowsR Documentation

Compute the first row of every group in a concatenated matrix.

Description

Compute the first row of every group in a concatenated matrix.

Usage

group.start.rows(lengths)

Arguments

lengths

integer vector, the number of rows of each group.

Value

integer vector with one entry per group.


fsbrain documentation built on Sept. 27, 2026, 1:07 a.m.