Simply runs list('lh' = lh_data, 'rh' = rh_data): A hemilist (short for hemisphere list) is just a named list with entries 'lh' and/or 'rh', which may contain anything. Hemilists are used as parameters and return values in many fsbrain functions. The 'lh' and 'rh' keys typically contain surfaces or vectors of morphometry data.
See also
Other hemilist functions:
hemilist.derive.hemi(),
hemilist.from.prefixed.list(),
hemilist.get.combined.data(),
hemilist.unwrap(),
hemilist.wrap(),
is.hemilist()