Create a hemilist from a named list with keys prefixed with 'lh_' and 'rh_'.
Source:R/hemilist.R
hemilist.from.prefixed.list.RdA hemilist is a named list with entries 'lh' and/or 'rh', see hemilist.
Arguments
- named_list
a named list, the keys must start with 'lh_' or 'rh_' to be assigned to the 'lh' and 'rh' entries of the returned hemilist. Other entries will be ignored.
- report_ignored
logical, whether to print a message with the ignored entries, if any.
- return_ignored
logical, whether to add a key 'ignored' to the returned hemilist, containing the ignored entries.
See also
Other hemilist functions:
hemilist(),
hemilist.derive.hemi(),
hemilist.get.combined.data(),
hemilist.unwrap(),
hemilist.wrap(),
is.hemilist()