Wrap data into a named hemi list.
Arguments
- data
something to wrap, typically some data for a hemisphere, e.g., a vector of morphometry data values. If NULL, the name will not be created.
- hemi
character string, one of 'lh' or 'rh'. The name to use for the data in the returned list.
- hemilist
optional
hemilist, an existing hemilist to add the entry to. If left at the default valueNULL, a new list will be created.
Value
a hemilist: a named list, with the 'data' in the name given by parameter 'hemi'
See also
Other hemilist functions:
hemilist(),
hemilist.derive.hemi(),
hemilist.from.prefixed.list(),
hemilist.get.combined.data(),
hemilist.unwrap(),
is.hemilist()