hex_colors_to_rgba_matrix: Convert a vector of hex colors to an Nx4 RGBA float matrix

View source: R/scimesh_bridge.R

hex_colors_to_rgba_matrixR Documentation

Convert a vector of hex colors to an Nx4 RGBA float matrix

Description

Convert a vector of hex colors to an Nx4 RGBA float matrix

Usage

hex_colors_to_rgba_matrix(hex_colors)

Arguments

hex_colors

character vector of hex color strings.

Value

Nx4 numeric matrix of RGBA values in the range 0..1.


fsbrain documentation built on Aug. 23, 2026, 5:06 p.m.