Highlight vertices given by index on a subject's meshes by coloring faces.
Source:R/highlight.R
highlight.vertices.on.subject.RdHighlight vertices given by index on a subject's meshes by coloring faces.
Arguments
- subjects_dir
string. The FreeSurfer SUBJECTS_DIR, i.e., a directory containing the data for all your subjects, each in a subdir named after the subject identifier.
- vis_subject_id
string. The subject identifier from which to obtain the surface for data visualization. Example: 'fsaverage'.
- verts_lh
integer vector, the indices of left hemisphere vertices.
- verts_rh
integer vector, the indices of right hemisphere vertices.
- surface
string. The display surface. E.g., "white", "pial", or "inflated". Defaults to "white".
- views
list of strings. Valid entries include: 'si': single interactive view. 't4': tiled view showing the brain from 4 angles. 't9': tiled view showing the brain from 9 angles.
- rgloptions
option list passed to
par3d. Example:rgloptions = list("windowRect"=c(50,50,1000,1000)).- rglactions
named list. A list in which the names are from a set of pre-defined actions. The values can be used to specify parameters for the action. The following example clips outliers in the data before plotting and writes a screenshot in PNG format:
rglactions = list("snapshot_png"="~/fsbrain.png", "clip_data"=c(0.05, 0.95)). Seerglactions.- color_bg
background color.
- color_verts_lh
vector of colors to visualize on the left hemisphere surface. Length must match number of vertices in 'verts_lh', or be a single color.
- color_verts_rh
vector of colors to visualize on the right hemisphere surface. Length must match number of vertices in 'verts_rh', or be a single color.
- k
integer, radius to extend neighborhood (for better visibility).
See also
Other visualization functions:
highlight.vertices.on.subject.spheres(),
vis.color.on.subject(),
vis.data.on.fsaverage(),
vis.data.on.subject(),
vis.labeldata.on.subject(),
vis.mask.on.subject(),
vis.region.values.on.subject(),
vis.rglwidget(),
vis.subject.annot(),
vis.subject.label(),
vis.subject.morph.native(),
vis.subject.morph.standard(),
vis.subject.pre(),
vis.symmetric.data.on.subject(),
vis.volume.on.surface(),
vislayout.from.coloredmeshes()
Other surface visualization functions:
highlight.vertices.on.subject.spheres(),
vis.color.on.subject()
Examples
if (FALSE) { # \dontrun{
fsbrain::download_optional_data();
subjects_dir = fsbrain::get_optional_data_filepath("subjects_dir");
highlight.vertices.on.subject(subjects_dir, 'subject1',
verts_lh=c(5000, 100000), verts_rh=c(300, 66666), views="si");
} # }