Get data limiting function, setting values inside range to NA.
Source:R/rglactions.R
limit_fun_na_inside.RdGet data limiting function to use in rglactions as 'trans_fun' to transform data.
Value
a function that takes as argument the data, and clips it to the requested range. I.e., values inside the range will be set to NA. Designed to be used as rglactions$trans_fun in vis functions.
Note
This is useful for thresholding data plotted with a background. All values inside the range will set to NA and be transparent, and thus be displayed as the background color.
See also
limit_fun_na which will set the values outside the range to NA.
Examples
rglactions = list("trans_fun"=limit_fun_na_inside(2,3));