Skip to contents

Get file names of optional data files which are available in the local package cache. You can access these files with get_optional_data_file().

Usage

list_optional_data()

Value

vector of strings. The file names available, relative to the package cache.