mergehemi.annots: Merge the annotations from two hemispheres into one annot.

View source: R/morph_atlas_agg.R

mergehemi.annotsR Documentation

Merge the annotations from two hemispheres into one annot.

Description

Merge the annotations from two hemispheres into one annot.

Usage

mergehemi.annots(lh_annot, rh_annot)

Arguments

lh_annot

annot. An annotation, as returned by freesurferformats::read.fs.annot().

rh_annot

annot. An annotation, as returned by freesurferformats::read.fs.annot().

Value

annot, the merged annotation.


fsbrain documentation built on Aug. 23, 2026, 5:06 p.m.