mesh.atlas.restrict.faces: Remove all faces that use one of the given vertices and...

View source: R/vis_mesh_atlas.R

mesh.atlas.restrict.facesR Documentation

Remove all faces that use one of the given vertices and renumber the remaining ones.

Description

Filter the faces of a mesh and renumber the vertex indices to refer to the reduced vertex list.

Usage

mesh.atlas.restrict.faces(faces, keep_mask)

Arguments

faces

integer matrix, one face per column, holding 1-based indices into the vertex list.

keep_mask

logical vector, one entry per vertex of the mesh, TRUE for the vertices which are kept.

Value

integer matrix like faces, with all faces removed that used a vertex which is not kept, and with the remaining vertex indices renumbered to refer to which(keep_mask).


fsbrain documentation built on Sept. 27, 2026, 1:07 a.m.