| mesh.ras2crs | R Documentation |
Applies the inverse of the FreeSurfer vox2ras_tkr matrix to all surface vertices, converting them from surface RAS coordinates to 0-based CRS (column, row, slice) indices. The resulting CRS coordinates can be used to directly index into a brain volume array (after adding 1 for R's 1-based indexing).
mesh.ras2crs(surface)
surface |
an |
a modified copy of the input surface with vertices in 0-based CRS space.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.