Return all faces which are made up completely of the listed vertices.
Source:R/helpers.R
mesh.vertex.included.faces.RdReturn all faces which are made up completely of the listed vertices.
Arguments
- surface_mesh
surface mesh, as loaded by
subject.surfaceorread.fs.surface.- source_vertices
integer vector, the vertex indices.
See also
Other surface mesh functions:
face.edges(),
label.border(),
mesh.vertex.neighbors(),
subject.surface(),
vis.path.along.verts()