| perform.na.mapping | R Documentation |
Usually this is done so that the NA values are plotted transparently, so your can see a background color through the respective colors.
perform.na.mapping(data, map_to_NA)
data |
numeric vector |
map_to_NA |
the value or value range that should be mapped to |
the mapped data
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.