Skip to contents

Perform data quality check based on a segstats table.

Usage

qc.from.segstats.table(filepath, ...)

Arguments

filepath

path to input file, a tab-separated file generated by running the FreeSurfer tools 'aparcstats2table' or 'asegstats2table'. The command line in the system shell would be something like 'aparcstats2table_bin –subjectsfile $subjects_file –meas $measure –hemi $hemi -t $aparc_output_table'.

...

parameters passed to qc.from.regionwise.df.

See also

Other quality check functions: qc.for.group(), qc.from.regionwise.df()