Skip to contents

Load a list of subjects from a subjects file, i.e., a simple text file containing one subject name per line.

Usage

read.md.subjects(subjects_file, header)

Arguments

subjects_file

character string, the path to the subjects file.

header

logical, whether the file starts with a header line.

Value

vector of strings, the subject identifiers.

Examples

   subjects_file = system.file("extdata", "subjects.txt", package = "fsbrain", mustWork = TRUE);
   subjects_list = read.md.subjects(subjects_file, header = FALSE);