renderables_to_line_layers: Collect the scimesh line layers of all fs.coloredpaths...

View source: R/scimesh_bridge.R

renderables_to_line_layersR Documentation

Collect the scimesh line layers of all fs.coloredpaths instances in a renderable list

Description

Walks a renderable list (a flat list of renderables, a hemilist, or a single renderable) and converts everything that is an fs.coloredpaths instance to scimesh line layers. Non-line renderables are ignored, they are handled by coloredmeshes_to_scimesh.

Usage

renderables_to_line_layers(renderables, style = "default")

Arguments

renderables

a renderable, or a (possibly nested) list of renderables.

style

a rendering style, see get.rglstyle.

Value

a list of scimesh line layers, possibly empty.


fsbrain documentation built on Sept. 27, 2026, 1:07 a.m.