rgl.coord.lines: Plot x, y and z axes in R,G,B.

View source: R/spherical.R

rgl.coord.linesR Documentation

Plot x, y and z axes in R,G,B.

Description

Plot positive x, y, and z axes from the center to 'len'. Gets added to current plot. Useful for debugging and understanding the rgl coordinate system.

Usage

rgl.coord.lines(len = 100)

Arguments

len

numeric scalar or vector of length 3, length of axes. You can specify a negative value to see the negative directions.

Value

NULL, called for the plotting side effect.

Note

The x, y and z axes are plotted in red, green, and blue, respectively.


fsbrain documentation built on Aug. 23, 2026, 5:06 p.m.