This function retrieves the global rgloptions defined in getOption('fsbrain.rgloptions'), or, if this is not set, returns the value from rglot.
Value
named list, usable as 'rgloptions' parameter for vis functions like vis.subject.morph.native.
This function retrieves the global rgloptions defined in getOption('fsbrain.rgloptions'), or, if this is not set, returns the value from rglot.
named list, usable as 'rgloptions' parameter for vis functions like vis.subject.morph.native.