surf.radius.fsaverage: Get pre-computed radius for fsaverage white surface.

View source: R/spherical.R

surf.radius.fsaverageR Documentation

Get pre-computed radius for fsaverage white surface.

Description

Get pre-computed radius for fsaverage white surface.

Usage

surf.radius.fsaverage(maxr = TRUE)

Arguments

maxr

logical, whether to return the maximum of the x, y, and z radii.

Value

If 'maxr' is TRUE, a numeric scalar representing the max of the x, y, and z radii, otherwise, a numerical vector of length 3 with all radii.

Note

The coordinates are for the white surface and in surface space, i.e., based on the raw values stored in the fsaverae/surf/lh.white and fsaverage/surf/rh.white files, without applying any transformation.

See Also

surfs.props, which was used to compute the returned values.


fsbrain documentation built on Aug. 23, 2026, 5:06 p.m.