| surfs.props | R Documentation |
Compute simple version of center and radius of 2 meshes.
surfs.props(lh, rh)
lh |
|
rh |
|
named list with entries 'center', 'radius', 'min' and 'max', each of which are numerical vectors of length 3, holding the x, y and z coordinates or values.
This function treats the 'lh' and 'rh' meshes as a single mesh, and computes the properties for this combined mesh.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.