Return coordinates for vertices, supporting entire brain via hemilist.
Source:R/highlight.R
vertex.coords.RdReturn coordinates for vertices, supporting entire brain via hemilist.
Arguments
- surface
an fs.surface instance, see
subject.surfacefunction. Can also be a hemilist of surfaces, in which case the vertices must be indices over both meshes (in range1..(nv(lh)+nv(rh))). If a hemilist, both entries must be surfaces (non-NULL).- vertices
vector of positive integers, the vertex indices. Values which are outside of the valid indices for the surface will be silently ignored, making it easier to work with the two hemispheres.
See also
Other 3d utility functions:
highlight.points.spheres(),
highlight.vertices.spheres()