Visualize a list of colored meshes in a single scene and rotate them, movie-style.
Source:R/vis_meshes.R
vis.coloredmeshes.rotating.RdVisualize a list of colored meshes in a single scene and rotate them, movie-style.
Arguments
- coloredmeshes
list of coloredmesh. A coloredmesh is a named list as returned by the coloredmesh.from.* functions. It has the entries 'mesh' of type tmesh3d, a 'col', which is a color specification for such a mesh.
- background
string, background color passed to rgl::bg3d()
- skip_all_na
logical, whether to skip (i.e., not render) meshes in the list that have the property 'rendner' set to FALSE. Defaults to TRUE. Practically, this means that a hemisphere for which the data was not given is not rendered, instead of being rendered in a single color.
- style
a named list of style parameters or a string specifying an available style by name (e.g., 'shiny'). Defaults to 'default', the default style.
- x
rotation x axis value, passed to
spin3d. Defaults to 0.- y
rotation y axis value, passed to
spin3d. Defaults to 1.- z
rotation z axis value, passed to
spin3d. Defaults to 0.- rpm
rotation rpm value, passed to
spin3d. Defaults to 15.- duration
rotation duration value, passed to
spin3d. Defaults to 20.- rgloptions
option list passed to
par3d. Example: rgloptions = list("windowRect"=c(50,50,1000,1000));- rglactions
named list. A list in which the names are from a set of pre-defined actions. Defaults to the empty list.