Visualize DTI tracks from Diffusion Toolkit/TrackVis TRK format file.
Source:R/vis_dti_tracks.R
vis.dti.trk.RdVisualize DTI tracks from Diffusion Toolkit/TrackVis TRK format file.
Usage
vis.dti.trk(
trk,
filter_tracks = list(min_length = 15, min_segment_count = 6),
color_by_orientation = FALSE
)Arguments
- trk
character string, the path to a TRK file that should be loaded. Alternatively, a loaded
trkinstance as returned byfreesurferformats::read.dti.trk.- filter_tracks
optional, named list of filters. Can contain fields
min_lengthandmin_segment_count. Set the whole thing toNULLor an entry to 0 for no filtering.- color_by_orientation
logical, whether to color the tracks by orientation. Slower, but may make the resulting visualization easier to interprete.
Value
The (loaded or received) trk instance. Note that this function is typically called for the side effect of visualization.
Note
The current simple implementation is very slow if the number of tracks becomes large (several thousand tracks).
Examples
if (FALSE) { # \dontrun{
# Create the following file with Diffusion Toolkit from your DTI data:
trk = freesurferformats::read.dti.trk("~/data/tim_only/tim/DICOM/dti.trk");
vis.dti.trk(trk);
} # }