Visualize several paths in different colors.
Arguments
- surface_vertices
float matrix of size (n, 3), the surface vertex coordinates, as returned as part of
subject.surfaceorread.fs.surface, in the member "vertices". Can also be afreesurferformats::fs.surfaceorrgl::tmesh3dinstance, in which case the coordinates are extracted automatically.- paths
list of positive integer vectors, the vertex indices of the paths
- color
a color string, like '#FF0000' to color the path.