vol.boundary.box.apply: Apply a boundary box to a volume, returning the inner volume...

View source: R/vis_volume.R

vol.boundary.box.applyR Documentation

Apply a boundary box to a volume, returning the inner volume part

Description

Apply a boundary box to a volume, returning the inner volume part

Usage

vol.boundary.box.apply(volume, bbox)

Arguments

volume

a 3D image volume

bbox

the boundary box

Value

a 3D image volume, the inner volume part, resulting from the application of the boundary box


fsbrain documentation built on Aug. 23, 2026, 5:06 p.m.