| vol.merge | R Documentation |
Merge background volume and overlay to new colors.
vol.merge(
volume,
overlay_colors,
bbox_threshold = 0L,
forced_overlay_color = NULL
)
volume |
3D array, can be numeric (gray-scale intensity values) or color strings. If numeric, the intensity values must be in range |
overlay_colors |
3D array of color strings, values which are not part of the overlay (and should display background in the result) must have |
bbox_threshold |
numerical, the threshold intensity used to separate background and foreground. All voxels with intensity values greater than this value in the background |
forced_overlay_color |
NULL or an rgb color string, like '#FF0000' for red. If NULL, the activation colors will be used as foreground colors. Otherwise, the given color will be for all foreground vertices. |
3D array of color strings, the merged colors
Other volume utility:
vol.boundary.box(),
vol.imagestack(),
vol.overlay.colors.from.activation(),
vol.planes(),
vol.slice()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.