| vol.overlay.colors.from.colortable | R Documentation |
Use the intensity values of the voxels in volume and lookup the respective colors in a colortable.
vol.overlay.colors.from.colortable(
volume,
colortable,
ignored_struct_indices = c(),
ignored_struct_names = c("unknown", "Unknown")
)
volume |
numeric 3D array, the values should be integers present in the |
colortable |
a colortable, as returned by |
ignored_struct_indices |
integer vector, |
ignored_struct_names |
vector of character strings, |
character string 3D array, the colors. Voxels in the volume which were not matched by the colortable are set to NA in it.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.