vol.warn.outside: Warn about surface vertices which are outside the volume.

View source: R/vol2surf.R

vol.warn.outsideR Documentation

Warn about surface vertices which are outside the volume.

Description

Warn about surface vertices which are outside the volume.

Usage

vol.warn.outside(outside, num_verts, clamp)

Arguments

outside

named list of logical vectors, per hemisphere (or NULL entries if the check was disabled).

num_verts

named list of integer scalars, the number of vertices per hemisphere.

clamp

logical, whether outside vertices were clamped to the volume border instead of being set to NA.

Value

NULL, called for the side effect of emitting a warning.


fsbrain documentation built on Sept. 27, 2026, 1:07 a.m.