volume.boxblur: Smooth a volume with a 3x3x3 box blur.

View source: R/volvis_shells.R

volume.boxblurR Documentation

Smooth a volume with a 3x3x3 box blur.

Description

Applies a separable 3x3x3 box blur to a 3D array, once per requested pass. Voxels at the border of the volume are treated as if the volume were padded with its edge values.

Usage

volume.boxblur(volume, passes = 1L)

Arguments

volume

a 3D numerical array.

passes

positive integer, the number of blur passes.

Value

a 3D numerical array with identical dimensions.


fsbrain documentation built on Sept. 27, 2026, 1:07 a.m.