volume.boxblur.axis: Apply a 1D 3-element box blur along one axis of a 3D array.

View source: R/volvis_shells.R

volume.boxblur.axisR Documentation

Apply a 1D 3-element box blur along one axis of a 3D array.

Description

Apply a 1D 3-element box blur along one axis of a 3D array.

Usage

volume.boxblur.axis(volume, axis = 1L)

Arguments

volume

a 3D numerical array.

axis

integer, the axis along which to blur (1, 2 or 3).

Value

a 3D numerical array with identical dimensions.


fsbrain documentation built on Sept. 27, 2026, 1:07 a.m.