Write per-vertex standard space data for a group of subjects to given file names.
Source:R/fsdir_abstraction_group.R
write.group.morph.standard.mf.RdWrite per-vertex standard space data for a group of subjects to given file names.
Arguments
- filepaths_hl
hemilistof vectors of character strings, the full paths to the output files, including file names and extension.- data_hl
hemilistof numerical matrix or data.frame, the morph data for the hemispheres of all subjects. Seegroupmorph.split.hemilistto get this format if you have a full matrix or dataframe for both hemispheres.- format
character string, a valid format spec for
freesurferformats::write.fs.morph, e.g., "auto" to derive from filename, "mgh", "mgz", "curv" or others.- create_dirs
logical, whether to create missing (sub) directories which occur in the 'filepaths'.
See also
write.group.morph.standard.sf to write the data to a single stacked file instead.