powered by
Implements the over alpha blending operation.
alphablend(front_color, back_color, silent = TRUE)
rgba color strings, the alpha-blended colors
rgba color strings, the upper color layer or foreground
rgba color strings, the lower color layer or background
logical, whether to suppress messages
see the Alpha blending section on https://en.wikipedia.org/wiki/Alpha_compositing
Other color functions: desaturate()
desaturate()