Skip to contents

This function will set all values in morphdata which are not part of the labeldata to NA (or whatever is specified by 'masked_data_value'). This is typically used to ignore values which are not part of the cortex (or any other label) during your analysis.

Usage

apply.labeldata.to.morphdata(morphdata, labeldata, masked_data_value = NA)

Arguments

morphdata

numerical vector, the morphometry data for one hemisphere

labeldata

integer vector or fs.label instance. A label as returned by subject.label.

masked_data_value

numerical, the value to set for all morphometry data values of vertices which are not part of the label. Defaults to NA.

Value

numerical vector, the masked data.