Apply a label to morphometry data.
Source:R/fsdir_abstraction_subject.R
apply.labeldata.to.morphdata.RdThis function will set all values in morphdata which are not part of the labeldata to NA (or whatever is specified by 'masked_data_value'). This is typically used to ignore values which are not part of the cortex (or any other label) during your analysis.
Arguments
- morphdata
numerical vector, the morphometry data for one hemisphere
- labeldata
integer vector or
fs.labelinstance. A label as returned bysubject.label.- masked_data_value
numerical, the value to set for all morphometry data values of vertices which are not part of the label. Defaults to NA.
See also
Other label functions:
apply.label.to.morphdata(),
subject.lobes(),
subject.mask(),
vis.labeldata.on.subject(),
vis.subject.label()
Other morphometry data functions:
apply.label.to.morphdata(),
group.morph.native(),
group.morph.standard(),
subject.morph.native(),
subject.morph.standard()