View source: R/vis_volume_3d.R
| apply.transform | R Documentation |
Apply affine transformation, like a vox2ras_tkr transformation, to input. This is just matrix multiplication for different input objects.
apply.transform(object, matrix_fun)
object |
numerical vector/matrix or Triangles3D instance, the coorindates or object to transform. |
matrix_fun |
a 4x4 affine matrix or a function returning such a matrix. If |
the input after application of the affine matrix (matrix multiplication)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.