Learn R Programming

fsbrain (version 1.0.0)

as.tract.bundle.list: Turn the various supported tract inputs into a list of bundles.

Description

Turn the various supported tract inputs into a list of bundles.

Usage

as.tract.bundle.list(
  tracts,
  coords = "ras",
  transform_matrix = NULL,
  max_tracks = Inf,
  skip_tracks = 0L,
  bbox = NULL,
  silent = FALSE
)

Value

named list of fs.tracts instances.

Arguments

tracts

see vis.tracts.

coords, transform_matrix, max_tracks, skip_tracks, bbox, silent

parameters passed on to read.tract.bundles if tracts is a file path or directory.