| check.segment.points | R Documentation |
Check whether a matrix is a valid point matrix for coloredpaths.
check.segment.points(x, arg_name)
x |
the object to check. |
arg_name |
character string, the name of the parameter, used in error messages. |
an (n, 3) numeric matrix.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.