Learn R Programming

fsbrain (version 1.0.0)

check.segment.points: Check whether a matrix is a valid point matrix for coloredpaths.

Description

Check whether a matrix is a valid point matrix for coloredpaths.

Usage

check.segment.points(x, arg_name)

Value

an (n, 3) numeric matrix.

Arguments

x

the object to check.

arg_name

character string, the name of the parameter, used in error messages.