View source: R/vis_volume_clusters.R
| cluster.shell.alpha | R Documentation |
The shells of a cluster are more transparent the closer they are to the threshold, and fully opaque at the highest level of their sign.
cluster.shell.alpha(level, threshold, levels, alpha_range = c(0.08, 1))
level |
single number, the iso-level of the shell. |
threshold |
single positive number, the cluster threshold. |
levels |
numerical vector of all iso-levels, see |
alpha_range |
numerical vector of length 2, the alpha value of the outermost and the innermost shell. |
single number between 0 and 1, the alpha value of the shell.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.