R/cbar.R
cm.cbry.Rd
Get cyan blue red yellow colormap function.
cm.cbry()
Returns a diverging palette with negative values in blue/cyan and positive ones in red/yellow, suitable for visualizing data that is centered around zero. Often used for clusters in neuroscience.