Compute surface color layer from annotation or atlas data.
Source:R/vis_surface_background.R
collayer.from.annotdata.RdCompute surface color layer from annotation or atlas data.
Arguments
- lh_annotdata
loaded annotation data for left hemi, as returned by
subject.annot- rh_annotdata
loaded annotation data for right hemi
Value
named hemi list, each entry is a vector of color strings, one color per surface vertex. The coloring represents the atlas data.
See also
You can plot the return value using vis.color.on.subject.
Other surface color layer:
collayer.bg(),
collayer.bg.atlas(),
collayer.bg.meancurv(),
collayer.bg.sulc(),
collayer.from.annot(),
collayer.from.mask.data(),
collayer.from.morphlike.data(),
collayers.merge()