Compute surface color layer from morph-like data.
Source:R/vis_surface_background.R
collayer.from.mask.data.RdCompute surface color layer from morph-like data.
Usage
collayer.from.mask.data(
lh_data = NULL,
rh_data = NULL,
makecmap_options = list(colFn = label.colFn)
)Arguments
- lh_data
integer vector, can be NULL
- rh_data
numerical vector, can be NULL
- makecmap_options
named list of parameters to pass to
makecmap. Must not include the unnamed first parameter, which is derived from 'measure'.
Value
named hemi list, each entry is a vector of color strings, one color per surface vertex. The coloring represents the label data.
See also
You can plot the return value using vis.color.on.subject.
Other surface color layer:
collayer.bg(),
collayer.bg.atlas(),
collayer.bg.meancurv(),
collayer.bg.sulc(),
collayer.from.annot(),
collayer.from.annotdata(),
collayer.from.morphlike.data(),
collayers.merge()