Compute surface color layer from morph-like data.
Source:R/vis_surface_background.R
collayer.from.morphlike.data.RdCompute surface color layer from morph-like data.
Arguments
- lh_morph_data
numerical vector, can be NULL
- rh_morph_data
numerical vector, can be NULL
- makecmap_options
named list of parameters to pass to
makecmap. Must not include the unnamed first parameter, which is derived from 'measure'.- return_metadata
logical, whether to return additional metadata as entry 'metadata' in the returned list
Value
named hemi list, each entry is a vector of color strings, one color per surface vertex. The coloring represents the morph data.
See also
You can plot the return value using vis.color.on.subject.
Other surface color layer:
collayer.bg(),
collayer.bg.atlas(),
collayer.bg.meancurv(),
collayer.bg.sulc(),
collayer.from.annot(),
collayer.from.annotdata(),
collayer.from.mask.data(),
collayers.merge()