Merge two or more color layers based on their transparency values.
Source:R/vis_surface_background.R
collayers.merge.RdMerge several color layers into one based on their transparency and alpha blending. In the final result, the lower layers are visible through the transparent or NA parts (if any) of the upper layers.
Arguments
- collayers
named list, the values must be vectors, matrices or arrays of color strings (as produced by
rgb. The names are free form and do not really matter. All values must have the same length.- opaque_background
a single color string or
NULL. If a color string, this color will be used as a final opaque background layer to ensure that the returned colors are all opaque. PassNULLto skip this, which may result in a return value that contains non-opaque color values.