View source: R/vis_surface_background.R
| collayers.merge | R Documentation |
Merge several color layers into one based on their transparency and alpha blending. In the final result, the lower layers are visible through the transparent or NA parts (if any) of the upper layers.
collayers.merge(collayers, opaque_background = "#FFFFFF")
collayers |
named list, the values must be vectors, matrices or arrays of color strings (as produced by |
opaque_background |
a single color string or |
a color layer, i.e., vector of color strings in a hemilist
Other surface color layer:
collayer.bg(),
collayer.bg.atlas(),
collayer.bg.meancurv(),
collayer.bg.sulc(),
collayer.from.annot(),
collayer.from.annotdata(),
collayer.from.mask.data(),
collayer.from.morphlike.data()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.