| coloredmesh.from.color | R Documentation |
Create a coloredmesh from a mesh and pre-defined colors.
coloredmesh.from.color(
subjects_dir,
subject_id,
color_data,
hemi,
surface = "white",
metadata = list(),
style = NULL
)
subjects_dir |
string. The FreeSurfer SUBJECTS_DIR, i.e., a directory containing the data for all your subjects, each in a subdir named after the subject identifier. |
subject_id |
string. The subject identifier. |
color_data |
vector of hex color strings, a single one or one per vertex. |
hemi |
string, one of 'lh' or 'rh'. The hemisphere name. Used to construct the names of the label data files to be loaded. |
surface |
character string or |
metadata |
a named list, can contain whatever you want. Typical entries are: 'src_data' a hemilist containing the source data from which the 'color_data' was created, optional. If available, it is encoded into the coloredmesh and can be used later to plot a colorbar. 'makecmap_options': the options used to created the colormap from the data. |
style |
|
coloredmesh. A named list with entries: "mesh" the tmesh3d mesh object. "col": the mesh colors. "render", logical, whether to render the mesh. "hemi": the hemisphere, one of 'lh' or 'rh'. If not NULL, also "style": the rendering style for this mesh.
You will usually not call this directly, but use coloredmeshes.from.color or vis.color.on.subject instead. It is exported for cases in which you want to build a single hemisphere of a scene manually.
Other coloredmesh functions:
Triangles3D.to.coloredmesh(),
coloredmesh.from.annot(),
coloredmesh.from.label(),
coloredmesh.from.mask(),
coloredmesh.from.morph.native(),
coloredmesh.from.morph.standard(),
coloredmesh.from.morphdata(),
coloredmeshes.from.color()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.