Create a coloredmesh from native space morphometry data.
Source:R/coloredmesh.R
coloredmesh.from.morph.native.RdCreate a coloredmesh from native space morphometry data.
Usage
coloredmesh.from.morph.native(
subjects_dir,
subject_id,
measure,
hemi,
surface = "white",
clip = NULL,
cortex_only = FALSE,
makecmap_options = mkco.seq()
)Arguments
- subjects_dir
string. The FreeSurfer SUBJECTS_DIR, i.e., a directory containing the data for all your subjects, each in a subdir named after the subject identifier.
- subject_id
string. The subject identifier.
- measure
string. The morphometry data to use. E.g., 'area' or 'thickness'. Pass NULL to render the surface in white, without any data. One can also pass the pre-loaded morphometry data as a numerical vector, the length of which must match the number of surface vertices.
- hemi
string, one of 'lh' or 'rh'. The hemisphere name. Used to construct the names of the label data files to be loaded.
- surface
character string or
fs.surfaceinstance. The display surface. E.g., "white", "pial", or "inflated". Defaults to "white".- clip
numeric vector of length 2 or NULL. If given, the 2 values are interpreted as lower and upper percentiles, and the morph data is clipped at the given lower and upper percentile (see
clip.data). Defaults to NULL (no data clipping).- cortex_only
logical, whether to mask the medial wall, i.e., whether the morphometry data for all vertices which are not part of the cortex (as defined by the label file
label/?h.cortex.label) should be replaced with NA values. In other words, setting this to TRUE will ignore the values of the medial wall between the two hemispheres. If set to true, the mentioned label file needs to exist for the subject. Defaults to FALSE.- makecmap_options
named list of parameters to pass to
makecmap. Must not include the unnamed first parameter, which is derived from 'measure'.
Value
coloredmesh. A named list with entries: "mesh" the tmesh3d mesh object. "col": the mesh colors. "render", logical, whether to render the mesh. "hemi": the hemisphere, one of 'lh' or 'rh'.