Create a coloredmesh from arbitrary data.
Usage
coloredmesh.from.morphdata(
subjects_dir,
vis_subject_id,
morph_data,
hemi,
surface = "white",
makecmap_options = mkco.seq()
)Arguments
- subjects_dir
string. The FreeSurfer SUBJECTS_DIR, i.e., a directory containing the data for all your subjects, each in a subdir named after the subject identifier.
- vis_subject_id
string. The subject identifier from which to obtain the surface for data visualization. Example: 'fsaverage'.
- morph_data
string. The morphometry data to use. E.g., 'area' or 'thickness.'
- hemi
string, one of 'lh' or 'rh'. The hemisphere name. Used to construct the names of the label data files to be loaded.
- surface
character string or
fs.surfaceinstance. The display surface. E.g., "white", "pial", or "inflated". Defaults to "white".- makecmap_options
named list of parameters to pass to
makecmap. Must not include the unnamed first parameter, which is derived from 'measure'.
Value
coloredmesh. A named list with entries: "mesh" the tmesh3d mesh object. "col": the mesh colors. "render", logical, whether to render the mesh. "hemi": the hemisphere, one of 'lh' or 'rh'.