View source: R/scimesh_bridge.R
| coloredmesh_to_scimesh | R Documentation |
Convert a single fs.coloredmesh to a scimesh mesh descriptor
coloredmesh_to_scimesh(cmesh, style = "default")
cmesh |
an fs.coloredmesh instance. |
style |
a rendering style: a style name, a named list of style parameters, or 'from_mesh' (use cmesh$style). Only the alpha value is consumed here (per-mesh vertex alpha). |
a scimesh mesh descriptor list with vertices, triangles, and colors.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.