View source: R/scimesh_bridge.R
| coloredpaths_to_scimesh | R Documentation |
Line segments have no mesh representation, so they cannot be
passed to the scimesh renderer as meshes. They are converted to scimesh
line layers instead (see scimesh::line_layer), which the scimesh
rasterizer draws directly, without creating any geometry. This is the
cheap way to draw many thin lines, like the edges of a connectome.
coloredpaths_to_scimesh(cpaths, style = "default")
cpaths |
an fs.coloredpaths instance. |
style |
a rendering style, see |
a list of scimesh line layers (class 'scimesh_lines'). One layer per distinct line width, because the width is a property of the layer.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.