Download the FreeSurfer v6 low-resolution fsaverage3 subject.
Source:R/optdata.R
download_fsaverage3.RdDownload some relevant files from the FreeSurfer v6 fsaverage3 subject. The files are subject to the FreeSurfer software license, see parameter 'accept_freesurfer_license' for details. This data is not required for the package to work. If you are working on a machine that has FreeSurfer installed, you already have this data anyways and do not need to download it.
Arguments
- accept_freesurfer_license
logical, whether you accept the FreeSurfer license for fsaverage, available at https://surfer.nmr.mgh.harvard.edu/fswiki/FreeSurferSoftwareLicense. Defaults to FALSE.
- scheme
character string, the URL scheme to use. Either
"https"(the default) or"http". Switching to"http"can be useful as a fallback if the HTTPS server is unreachable.