Download extra data to reproduce the figures from the fsbrain paper.
Source:R/optdata.R
download_optional_paper_data.RdDownload extra data to reproduce the figures from the fsbrain paper.
R/optdata.R
download_optional_paper_data.RdDownload extra data to reproduce the figures from the fsbrain paper.