Draws a set of line segments (as returned by mesh.slice.intersection) onto a magick image. Individual mesh triangles produce small segments, which collectively trace the contour boundary when drawn together.
draw.segments.on.image(
img,
segments,
slice_axis,
row_axis,
col_axis,
color = "#FF0000",
lwd = 1,
coord_scale = 1L
)the modified magick image (invisibly).
a magick image instance (a single 2D slice image).
list of 2×2 matrices, each a line segment in 0-based CRS coordinates on the two orthogonal axes.
integer, the axis (1,2,3) perpendicular to the slice plane.
integer, which CRS axis (1, 2, or 3) maps to the image row dimension.
integer, which CRS axis (1, 2, or 3) maps to the image column dimension.
character string, the color for the contour lines.
numeric, line width passed to segments. Defaults to 1.
positive integer, the factor by which the CRS coordinates must be multiplied to map them to image pixel coordinates. Defaults to 1L, which maps coordinates 1:1 to pixels (as is the case when the image is at native resolution). Use larger values when drawing onto a scaled-up image or overlay.