Export a coloredmeshes with vertexcolors in PLY format.
Source:R/export.R
export.coloredmesh.ply.RdExports coloredmeshes with vertex coloring to standard mesh files in Stanford Triangle (PLY) format. This is very hand for rendering in external standard 3D modeling software like Blender.
Arguments
- filepath
The export filepath, including file name and extension.
- coloredmesh
an 'fs.coloredmesh' instance, as returned (silently) by all surface visualization functions, like
vis.subject.morph.native.
Examples
if (FALSE) { # \dontrun{
fsbrain::download_optional_data();
subjects_dir = fsbrain::get_optional_data_filepath("subjects_dir");
coloredmeshes = vis.subject.morph.native(subjects_dir, 'subject1', 'thickness');
export.coloredmesh.ply('~/subject1_thickness_lh.ply', coloredmeshed$lh);
} # }