View source: R/scimesh_bridge.R
| filter_scene_by_view | R Documentation |
Filter a scimesh scene to the meshes visible from a given view
filter_scene_by_view(scene, hemi_filter)
scene |
a named list of scimesh mesh descriptors (with "lh" and/or "rh" entries). |
hemi_filter |
character string, one of "lh", "rh", or "both". |
a flat list of scimesh mesh descriptors for the given view.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.