Learn R Programming

fsbrain (version 0.6.0)

fsbrain.renderable: Check whether object can be rendered by fsbrain

Description

Check whether object can be rendered by fsbrain

Usage

fsbrain.renderable(x)

Value

TRUE if x is an instance of a class that can be rendered by fsbrain visualization functions, and FALSE otherwise. Currently, the following types are renderable: fs.coloredvoxels, fs.coloredmesh, Triangles3D.

Arguments

x

any R object

See Also

is.Triangles3D