geodesic.dists.to.vertex: Simple internal wrapper around Rvcg::vcgDijkstra with function check.
Description
Simple internal wrapper around Rvcg::vcgDijkstra with function check.
Usage
geodesic.dists.to.vertex(mesh, v)
Value
double vector with length equal to num vertices in the mesh, the geodesic distances from all other vertices to the query vertex v.
Arguments
- mesh
a tmesh3d instance.
- v
positive integer, a vertex index in the mesh.