get.fsbrain.scimesh.output.dims: Get the output image dimensions for the scimesh backend

View source: R/scimesh_bridge.R

get.fsbrain.scimesh.output.dimsR Documentation

Get the output image dimensions for the scimesh backend

Description

Get the output image dimensions for the scimesh backend

Usage

get.fsbrain.scimesh.output.dims()

Value

integer vector of length 2 (width, height), read from the global option 'fsbrain.scimesh.output_dims'. Defaults to 1920x1080.


fsbrain documentation built on Aug. 23, 2026, 5:06 p.m.