Learn R Programming

fsbrain (version 0.7.0)

get.fsbrain.scimesh.output.dims: Get the output image dimensions for the scimesh backend

Description

Get the output image dimensions for the scimesh backend

Usage

get.fsbrain.scimesh.output.dims()

Arguments

Value

integer vector of length 2 (width, height), read from the global option 'fsbrain.scimesh.output_dims'. Defaults to 1920x1080.