Get the default visualization style parameters as a named list.
Source:R/vis_meshes.R
get.rglstyle.RdRun material3d without arguments to see valid style keywords to create new styles.
Value
a style, resolved to a parameter list compatible with material3d.
See also
shade3d can use the returned style