| get.rglstyle | R Documentation |
Run material3d without arguments to see valid style keywords to create new styles.
get.rglstyle(style)
style |
string. A style name. Available styles are one of: "default", "shiny", "semitransparent", "glass", "edges". |
a style, resolved to a parameter list compatible with material3d.
In addition to the style names listed above, the magic word 'from_mesh' can be passed as parameter 'style' to the rendering functions: it makes them use the style stored in the 'style' field of each individual mesh (see coloredmesh.from.color). This allows you to give individual meshes of a scene their own look, e.g., to render a cortex mesh semi-transparently behind colored data meshes, see vis.subcortical.region.values. Note that the scimesh renderer backend currently only supports the alpha channel of a style, not other material properties.
shade3d can use the returned style
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.