group.start.rows: Compute the first row of every group in a concatenated matrix.
Description
Compute the first row of every group in a concatenated matrix.
Usage
group.start.rows(lengths)
Value
integer vector with one entry per group.
Arguments
- lengths
integer vector, the number of rows of each group.