A hemilist is a named list with entries 'lh' and/or 'rh', see hemilist.
hemilist.from.prefixed.list(
named_list,
report_ignored = TRUE,
return_ignored = FALSE
)a named list, the keys must start with 'lh_' or 'rh_' to be assigned to the 'lh' and 'rh' entries of the returned hemilist. Other entries will be ignored.
logical, whether to print a message with the ignored entries, if any.
logical, whether to add a key 'ignored' to the returned hemilist, containing the ignored entries.
a hemilist
Other hemilist functions:
hemilist.derive.hemi(),
hemilist.get.combined.data(),
hemilist.unwrap(),
hemilist.wrap(),
hemilist(),
is.hemilist()