Unwrap hemi data from a named hemi list.
Arguments
- hemi_list
named list, can have entries 'lh' and/or 'rh', see
hemilist.- hemi
character string, the hemi data name to retrieve from the list. Can be NULL if the list only has a single entry.
- allow_null_list
logical, whether to silently return NULL instead of raising an error if 'hemi_list' is NULL
See also
Other hemilist functions:
hemilist(),
hemilist.derive.hemi(),
hemilist.from.prefixed.list(),
hemilist.get.combined.data(),
hemilist.wrap(),
is.hemilist()