Meshes and coordinates that were computed from a volume array in R are expressed in 1-based R array indices: the first voxel of the volume is at index 1, the second at index 2, and so on. This is the convention of the iso-surfaces returned by shell.extract.mesh and volvis.contour, and of the indices returned by which(volume != 0, arr.ind = TRUE).
The FreeSurfer vox2ras_tkr matrix, in contrast, expects 0-based CRS (column, row, slice) indices: the first voxel of the volume is at CRS (0, 0, 0), and (as the name says) the voxel index is mapped to RAS. Feeding 1-based R indices to vox2ras_tkr() shifts the result by one voxel (1 mm for a conformed volume), which is why volume data seemed to be slightly offset from the brain surface it was rendered with.
This function returns the matrix which maps 1-based R array indices to surface RAS, i.e., vox2ras_tkr() %*% translation.matrix(-1, -1, -1). It is used internally by the volume visualization functions, and can be used to transform the meshes returned by volvis.contour (or misc3d::contour3d) so that they are aligned with surface renderings of the same subject.