Learn R Programming

fsbrain (version 0.6.0)

limit_fun_na: Get data limiting function to NA.

Description

Get data limiting function to use in rglactions as 'trans_fun' to transform data. This is typically used to limit the colorbar in a plot to a certain range. This is similar to clip.data, but uses absolute values instead of percentiles to clip.

Usage

limit_fun_na(vmin, vmax)

Value

a function that takes as argument the data, and clips it to the requested range. I.e., values outside the range will be set to NA. Designed to be used as rglactions$trans_fun in vis functions, to limit the colorbar and data range.

Arguments

vmin

numerical scalar, the lower border. Data values below this will be set to NA in the return value.

vmax

numerical scalar, the upper border. Data values above this will be set to NA in the return value.

See Also

limit_fun_na_inside which will set the values inside the range to NA.

Examples

Run this code
   rglactions = list("trans_fun"=limit_fun_na(2,3));

Run the code above in your browser using DataLab