limit_fun_na_inside: Get data limiting function, setting values inside range to NA.
Description
Get data limiting function to use in rglactions as 'trans_fun' to transform data.
Usage
limit_fun_na_inside(vmin, vmax)
Value
a function that takes as argument the data, and clips it to the requested range. I.e., values inside the range will be set to NA. Designed to be used as rglactions$trans_fun in vis functions.
Arguments
vmin
numerical scalar, the lower border. Data values between this and vmax will be set to NA in the return value.
vmax
numerical scalar, the upper border. See 'vmin'.
See Also
limit_fun_na which will set the values outside the range to NA.