| list.tract.bundle.files | R Documentation |
List the bundle files of a tract atlas directory.
list.tract.bundle.files(atlas_dir)
atlas_dir |
character string, the path to the directory. |
vector of character strings, the paths of the bundle files (sorted), or an empty vector if the directory does not exist or contains no bundle files.
The file name filter is important: the downloaded archives contain macOS resource fork files ('._AC.trk' and friends), which are not tract files.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.