Learn R Programming

fsbrain (version 1.0.0)

list.tract.bundle.files: List the bundle files of a tract atlas directory.

Description

List the bundle files of a tract atlas directory.

Usage

list.tract.bundle.files(atlas_dir)

Value

vector of character strings, the paths of the bundle files (sorted), or an empty vector if the directory does not exist or contains no bundle files.

Arguments

atlas_dir

character string, the path to the directory.