Check that the surface mesh and the annotation files of a mesh atlas exist for a subject, and stop with a helpful error message otherwise.
mesh.atlas.check.files(subjects_dir, subject_id, atlas, surface)vector of strings, the file paths of the atlas files, invisibly. The function stops if any of the files is missing.
string. The FreeSurfer SUBJECTS_DIR, i.e., a directory containing the data for all your subjects, each in a subdir named after the subject identifier.
string. The subject identifier.
string. The atlas name, used to construct the annotation file name.
string. The name of the surface mesh that belongs to the atlas.