View source: R/vis_mesh_atlas.R
| mesh.atlas.context.layer | R Documentation |
Compute the optional context mesh (typically a semi-transparent cortex) that is rendered together with the data meshes of a mesh atlas.
mesh.atlas.context.layer(subjects_dir, subject_id, cortex)
subjects_dir |
string, the subjects dir to use for the context mesh. |
subject_id |
string, the subject id to use for the context mesh. |
cortex |
the context definition. Either a character string (the name of the surface mesh to
use, e.g., 'white'), a named list of options for the context mesh (supported entries are
'surface', 'color', 'alpha', 'style', 'subjects_dir' and 'subject_id'), an
|
a named list with entries 'lh' and 'rh', the context coloredmeshes.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.