Compute the optional context mesh (typically a semi-transparent cortex) that is rendered together with the data meshes of a mesh atlas.
mesh.atlas.context.layer(subjects_dir, subject_id, cortex)a named list with entries 'lh' and 'rh', the context coloredmeshes.
string, the subjects dir to use for the context mesh.
string, the subject id to use for the context mesh.
the context definition. Either a character string (the name of the surface mesh to
use, e.g., 'white'), a named list of options for the context mesh (supported entries are
'surface', 'color', 'alpha', 'style', 'subjects_dir' and 'subject_id'), an
fs.coloredmesh instance, or a hemilist of such instances (which is then used as-is).