Compute the paths of the surface mesh and annotation files of a mesh atlas.
The files are not required to exist, see mesh.atlas.check.files.
mesh.atlas.file.paths(subjects_dir, subject_id, atlas, surface)vector of strings, the file paths of the atlas files.
string. The FreeSurfer SUBJECTS_DIR, i.e., a directory containing the data for all your subjects, each in a subdir named after the subject identifier.
string. The subject identifier.
string. The atlas name, used to construct the annotation file name.
string. The name of the surface mesh that belongs to the atlas.