Filter the faces of a mesh and renumber the vertex indices to refer to the reduced vertex list.
mesh.atlas.restrict.faces(faces, keep_mask)integer matrix like faces, with all faces removed that used a vertex which is not kept, and with the remaining vertex indices renumbered to refer to which(keep_mask).
integer matrix, one face per column, holding 1-based indices into the vertex list.
logical vector, one entry per vertex of the mesh, TRUE for the vertices which are kept.