Applies the inverse of the FreeSurfer vox2ras_tkr matrix to all surface vertices, converting them from surface RAS coordinates to 0-based CRS (column, row, slice) indices. The resulting CRS coordinates can be used to directly index into a brain volume array (after adding 1 for R's 1-based indexing).
mesh.ras2crs(surface)a modified copy of the input surface with vertices in 0-based CRS space.
an fs.surface instance, as returned by read.fs.surface.