| normalize.region.names | R Documentation |
Removes all characters which are not letters or digits and lowercases the result, so that region names which differ only in their formatting (like 'LH_Vis_1' and 'lh vis 1') can be matched.
normalize.region.names(x)
x |
vector of character strings. |
vector of character strings, the normalized names.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.