Learn R Programming

fsbrain (version 1.0.0)

normalize.region.names: Normalize a region name for matching.

Description

Removes all characters which are not letters or digits and lowercases the result, so that region names which differ only in their formatting (like 'LH_Vis_1' and 'lh vis 1') can be matched.

Usage

normalize.region.names(x)

Value

vector of character strings, the normalized names.

Arguments

x

vector of character strings.