Load a list of subjects from a subjects file, i.e., a simple text file containing one subject name per line.
See also
Other metadata functions:
demographics.to.fsgd.file(),
read.md.demographics(),
report.on.demographics()
Examples
subjects_file = system.file("extdata", "subjects.txt", package = "fsbrain", mustWork = TRUE);
subjects_list = read.md.subjects(subjects_file, header = FALSE);