| segment.orientation.colors | R Documentation |
Computes the classic DTI orientation colors, i.e., segments running left-right, anterior-posterior and superior-inferior get different colors (red, green and blue for the 'axis' mode).
segment.orientation.colors(from, to, mode = c("axis", "rgb"))
from |
matrix of segment start points, see |
to |
matrix of segment end points, same size as |
mode |
character string, either 'axis' (every segment gets one fully saturated color, based on the dominant direction axis) or 'rgb' (the color channels are the absolute direction components, which gives smoother but paler colors). |
vector of hex color strings, one per segment.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.