View source: R/volvis_shells.R
| shell.coloredmeshes | R Documentation |
Creates one fs.coloredmesh per shell, each with its own color and alpha value stored in the mesh style.
shell.coloredmeshes(
meshes,
levels,
colors = NULL,
alphas = NULL,
palette = "grey_context",
alpha_range = NULL
)
meshes |
list of |
levels |
numerical vector of the iso-levels, ascending. |
colors |
character vector of colors or |
alphas |
numerical vector of alpha values or |
palette |
character string, the name of the palette, see |
alpha_range |
numerical vector of length 2 or |
list of fs.coloredmesh instances, one per shell.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.