Creates one fs.coloredmesh per shell, each with its own color and alpha value stored in the mesh style.
shell.coloredmeshes(
meshes,
levels,
colors = NULL,
alphas = NULL,
palette = "grey_context",
alpha_range = NULL
)list of fs.coloredmesh instances, one per shell.
list of mesh3d instances, one per shell.
numerical vector of the iso-levels, ascending.
character vector of colors or NULL to use the colors of the palette.
numerical vector of alpha values or NULL to use the alphas of the palette.
character string, the name of the palette, see shell.palette.
numerical vector of length 2 or NULL, passed to shell.palette.