View source: R/volvis_shells.R
| shell.cut.away | R Documentation |
Removes all faces of a mesh which are (partially) located in the given anatomical direction of a cut plane, so that one can look inside the object. The mesh is not closed at the cut plane.
shell.cut.away(mesh, cut_away = "right", cut_fraction = 0.5)
mesh |
a |
cut_away |
character string, one of 'left', 'right', 'posterior', 'anterior', 'inferior' or 'superior'. |
cut_fraction |
numerical, the position of the cut plane along the respective axis, as a fraction of the bounding box of the mesh. |
a mesh3d instance with the respective faces removed.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.