Removes all faces of a mesh which are (partially) located in the given anatomical direction of a cut plane, so that one can look inside the object. The mesh is not closed at the cut plane.
shell.cut.away(mesh, cut_away = "right", cut_fraction = 0.5)a mesh3d instance with the respective faces removed.
a mesh3d instance, in surface RAS coordinates.
character string, one of 'left', 'right', 'posterior', 'anterior', 'inferior' or 'superior'.
numerical, the position of the cut plane along the respective axis, as a fraction of the bounding box of the mesh.