View source: R/volvis_shells.R
| shell.levels | R Documentation |
Compute the iso-levels of the shells.
shell.levels(
volume,
levels = NULL,
num_levels = 5L,
level_type = "quantile",
level_range = c(0.2, 0.95)
)
volume |
a 3D numerical array. |
levels |
numerical vector or |
num_levels |
positive integer, the number of shells to compute if |
level_type |
character string, 'quantile' or 'linear'. |
level_range |
numerical vector of length 2, the range from which the levels are taken. |
ascending numerical vector of levels, the outermost shell first.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.