Compute the iso-levels of the shells.
shell.levels(
volume,
levels = NULL,
num_levels = 5L,
level_type = "quantile",
level_range = c(0.2, 0.95)
)ascending numerical vector of levels, the outermost shell first.
a 3D numerical array.
numerical vector or NULL, the levels given by the user.
positive integer, the number of shells to compute if levels is NULL.
character string, 'quantile' or 'linear'.
numerical vector of length 2, the range from which the levels are taken.