View source: R/volvis_shells.R
| shell.volume.data | R Documentation |
Accepts a 3D array or an fs.volume instance, and selects the requested frame of a 4D volume.
shell.volume.data(volume, frame = 1L)
volume |
a 3D numerical array or an |
frame |
positive integer, the frame to use for a 4D volume. |
a 3D numerical array.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.