Learn R Programming

fsbrain (version 1.0.0)

shell.volume.data: Extract the 3D data array of a volume.

Description

Accepts a 3D array or an fs.volume instance, and selects the requested frame of a 4D volume.

Usage

shell.volume.data(volume, frame = 1L)

Value

a 3D numerical array.

Arguments

volume

a 3D numerical array or an fs.volume instance.

frame

positive integer, the frame to use for a 4D volume.