View source: R/vis_multiview.R
| shift.hemis.apart | R Documentation |
Modify mesh coordinates of a hemilist of coloredmeshes to introduce a gap between the two hemispheres.
shift.hemis.apart(
coloredmeshes_hl,
shift_by = NULL,
axis = 1L,
hemi_order_on_axis = "lr",
min_dist = 0
)
coloredmeshes_hl |
hemilist of coloredmeshes |
shift_by |
numerical vector of length 2, the amount by which to shift the hemis. The first value is for the left hemi, the second for the right hemi (values can be negative). Pass |
axis |
positive integer, one of 1L, 2L or 3L. The axis on which to shift (x,y,z). |
hemi_order_on_axis |
character string, one of 'auto', 'auto_flipped', 'lr' or 'rl'. Defines how to determine the order of the hemis on the axes. This is ignored unless 'shift_by' is |
min_dist |
numerical scalar, the minimal distance of the hemispheres. Ignored unless 'shift_by' is |
hemilist of coloredmeshes, the shifted meshes
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.