| streamlines.to.segments | R Documentation |
Converts streamlines (a list of point sequences) into the pair of
point matrices that describes the line segments between their consecutive
points, which is the representation used by fs.coloredpaths.
This is vectorized: the segments of all streamlines are computed in one go,
no matter how many there are.
streamlines.to.segments(tracts)
tracts |
an |
named list with entries from (matrix of segment start points),
to (matrix of segment end points) and lengths (integer vector,
the number of segments of each streamline).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.