| surface.interpolate.frac | R Documentation |
Computes a new mesh whose vertex positions lie on the line between the corresponding vertices of two meshes with identical vertex counts, e.g., between the white and the pial surface. This is what the FreeSurfer command line option --surf-frac does.
surface.interpolate.frac(surface_a, surface_b, frac)
surface_a |
an |
surface_b |
an |
frac |
numeric scalar, the fraction, in range 0..1. |
numeric matrix of vertex coordinates (see surface_a$vertices).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.