Learn R Programming

fsbrain (version 1.0.0)

surface.interpolate.frac: Compute the vertex positions at a given fraction between two surfaces.

Description

Computes a new mesh whose vertex positions lie on the line between the corresponding vertices of two meshes with identical vertex counts, e.g., between the white and the pial surface. This is what the FreeSurfer command line option --surf-frac does.

Usage

surface.interpolate.frac(surface_a, surface_b, frac)

Value

numeric matrix of vertex coordinates (see surface_a$vertices).

Arguments

surface_a

an fs.surface instance, the surface at fraction 0.

surface_b

an fs.surface instance, the surface at fraction 1. Must have the same number of vertices as surface_a.

frac

numeric scalar, the fraction, in range 0..1.