Learn R Programming

fsbrain (version 1.0.0)

values.to.colorlayer: Map values to a color layer and the matching colorbar metadata.

Description

Map values to a color layer and the matching colorbar metadata.

Usage

values.to.colorlayer(values, makecmap_options)

Value

named list with entries 'colors' (the hex color strings for the values) and 'makecmap_options' (the input options, extended with the effective range, for use as colorbar metadata).

Arguments

values

numeric vector, the values to map to colors.

makecmap_options

named list of parameters to pass to makecmap, see mkco.seq. Supported entries are 'colFn', 'n', 'symm' and 'col.na'.