Map values to a color layer and the matching colorbar metadata.
values.to.colorlayer(values, makecmap_options)named list with entries 'colors' (the hex color strings for the values) and 'makecmap_options' (the input options, extended with the effective range, for use as colorbar metadata).
numeric vector, the values to map to colors.
named list of parameters to pass to makecmap, see mkco.seq. Supported entries are 'colFn', 'n', 'symm' and 'col.na'.