View source: R/scimesh_bridge.R
| view_angle_to_scimesh_camera | R Documentation |
Translates an fsbrain view_angle string (e.g., "lateral_lh", "dorsal", etc.) to a scimesh camera specification. The returned object includes the camera list and a hemi_filter field indicating which hemispheres to render for this view.
view_angle_to_scimesh_camera(scene, view_angle)
scene |
a named list of scimesh mesh descriptors with "lh" and/or "rh"
entries, as returned by |
view_angle |
character string, a valid view angle. See
|
a list with entries: camera (scimesh camera list from
camera_auto), and hemi_filter (one of "lh", "rh", or "both").
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.