With camera-based views, geometry (and text) stays in world coordinates while the camera applies the view rotation. To keep a label at the same screen position relative to the (now unrotated) renderables as in the legacy mesh-rotation views, the label offset is pre-rotated by the view's mesh rotation matrix R_mesh.
view_label3d(text, x, y, z, R_mesh = NULL)character string, the label text.
y, z numeric, the label offset in the rotated (view) frame.
4x4 numeric rotation matrix, the view's mesh rotation (use
rotation.matrix), or NULL for no rotation (e.g.,
the dorsal view).