Visualize pre-defined vertex colors on a subject.
Arguments
- subjects_dir
string. The FreeSurfer SUBJECTS_DIR, i.e., a directory containing the data for all your subjects, each in a subdir named after the subject identifier.
- vis_subject_id
string. The subject identifier from which to obtain the surface for data visualization. Example: 'fsaverage'.
- color_lh
vector of colors to visualize on the left hemisphere surface. Length must match number of vertices in hemi surface, or be a single color.
- color_rh
vector of colors to visualize on the right hemisphere surface. Length must match number of vertices in hemi surface, or be a single color.
- surface
string. The display surface. E.g., "white", "pial", or "inflated". Defaults to "white".
- views
list of strings. Valid entries include: 'si': single interactive view. 't4': tiled view showing the brain from 4 angles. 't9': tiled view showing the brain from 9 angles.
- rgloptions
option list passed to
par3d. Example:rgloptions = list("windowRect"=c(50,50,1000,1000)).- rglactions
named list. A list in which the names are from a set of pre-defined actions. The values can be used to specify parameters for the action. The following example clips outliers in the data before plotting and writes a screenshot in PNG format:
rglactions = list("snapshot_png"="~/fsbrain.png", "clip_data"=c(0.05, 0.95)). Seerglactions.- color_both
vector of colors to visualize on the left and right hemispheres. Alternative to 'color_lh' and 'color_rh'. Length must match sum of vertices in both hemis. Can also be a hemilist.
- style
character string or rgl rendering style, see
get.rglstyle.
See also
Other visualization functions:
highlight.vertices.on.subject(),
highlight.vertices.on.subject.spheres(),
vis.data.on.fsaverage(),
vis.data.on.subject(),
vis.labeldata.on.subject(),
vis.mask.on.subject(),
vis.region.values.on.subject(),
vis.rglwidget(),
vis.subject.annot(),
vis.subject.label(),
vis.subject.morph.native(),
vis.subject.morph.standard(),
vis.subject.pre(),
vis.symmetric.data.on.subject(),
vis.volume.on.surface(),
vislayout.from.coloredmeshes()
Other surface visualization functions:
highlight.vertices.on.subject(),
highlight.vertices.on.subject.spheres()
Examples
if (FALSE) { # \dontrun{
fsbrain::download_optional_data();
subjects_dir = fsbrain::get_optional_data_filepath("subjects_dir");
color_lh = '#ff0000';
num_verts_subject1_rh = 153333;
color_rh = rep('#333333', num_verts_subject1_rh);
color_rh[1:30000] = '#00ff00';
color_rh[30001:60000] = '#ff0000';
color_rh[60001:90000] = '#0000ff';
color_rh[90001:120000] = '#ffff00';
color_rh[120001:150000] = '#00ffff';
vis.color.on.subject(subjects_dir, 'subject1', color_lh, color_rh);
} # }