| vis.coloredpaths | R Documentation |
Uses rgl::segments3d, i.e., hardware lines, so that a line is always one pixel wide (times the requested width) no matter how far away it is from the camera. Segments which share a line width are drawn in a single call, because the line width is a material property (like the color, which can be set per segment).
vis.coloredpaths(cpaths, style = "default")
cpaths |
an fs.coloredpaths instance. |
style |
a rendering style, see |
invisible NULL.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.