Learn R Programming

fsbrain (version 1.0.0)

vol.apply.cortex.mask: Apply the cortex mask to projected data.

Description

Apply the cortex mask to projected data.

Usage

vol.apply.cortex.mask(data, subjects_dir, subject_id, cortex_label = "cortex")

Value

named list of numeric vectors, with medial wall values set to NA.

Arguments

data

named list of numeric vectors, per hemisphere.

subjects_dir

character string, the subjects dir holding the label files.

subject_id

character string, the subject/template identifier.

cortex_label

character string, the name of the cortex label file (or the loaded label data).