Apply the cortex mask to projected data.
vol.apply.cortex.mask(data, subjects_dir, subject_id, cortex_label = "cortex")named list of numeric vectors, with medial wall values set to NA.
named list of numeric vectors, per hemisphere.
character string, the subjects dir holding the label files.
character string, the subject/template identifier.
character string, the name of the cortex label file (or the loaded label data).