Apply a boundary box to a volume, returning the inner volume part
Source:R/vis_volume.R
vol.boundary.box.apply.RdApply a boundary box to a volume, returning the inner volume part
R/vis_volume.R
vol.boundary.box.apply.RdApply a boundary box to a volume, returning the inner volume part