| vol.find.file | R Documentation |
Takes a volume specification (a filepath, a name without extension, or an in-memory volume) and computes the filepath of the volume file on disk.
vol.find.file(volume, default_dir = NULL)
volume |
character string or named list. If a character string and the file exists, it is interpreted as the volume filepath. If it does not exist, it is interpreted as the volume name without extension, resolved against |
default_dir |
character string or NULL, the directory to resolve volume names against, typically the |
character string, the volume filepath, or NULL if volume is an in-memory volume.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.