| vol.load | R Documentation |
Load a volume (from file or memory) and return the data along with the affine transformation.
vol.load(volume, default_dir = NULL, affine = NULL, vox2ras = "auto")
volume |
character string or named list. If a string, either a volume filepath or the name of a volume file without extension. If a named list, an in-memory volume with entries 'data' (numeric 3D or 4D array) and 'affine' (4x4 numeric matrix mapping 0-based voxel indices to world coordinates). |
default_dir |
character string or NULL, the directory used to resolve volumes specified as names without extension. |
affine |
numeric 4x4 matrix or |
vox2ras |
character string, how to compute the transformation from voxel indices to world coordinates for the volume: 'auto' (the default) uses |
named list with entries 'data', 'affine' and 'filepath' (see vol.read.file.with.affine).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.