Merge background volume and overlay to new colors.
Arguments
- volume
3D array, can be numeric (gray-scale intensity values) or color strings. If numeric, the intensity values must be in range
[0, 1].- overlay_colors
3D array of color strings, values which are not part of the overlay (and should display background in the result) must have
NAinstead of a color string. Must have same dimensions as thevolume.- bbox_threshold
numerical, the threshold intensity used to separate background and foreground. All voxels with intensity values greater than this value in the background
volumewill be consideredforegroundvoxels. Background-only slices at the borders of the volume will be discarded (in the merged, final image). PassNULLto use the full image without applying any bounding box.- forced_overlay_color
NULL or an rgb color string, like '#FF0000' for red. If NULL, the activation colors will be used as foreground colors. Otherwise, the given color will be for all foreground vertices.
See also
Other volume utility:
vol.boundary.box(),
vol.imagestack(),
vol.overlay.colors.from.activation(),
vol.planes(),
vol.slice()