Compute voxel colors based on colortable.
Source:R/vis_volume.R
vol.overlay.colors.from.colortable.RdUse the intensity values of the voxels in volume and lookup the respective colors in a colortable.
Arguments
- volume
numeric 3D array, the values should be integers present in the
struct_indexcolumn of the colortable. All other values will be assignedNAas a color.- colortable
a colortable, as returned by
read.fs.colortable, or a character string representing a path to a colortable file.- ignored_struct_indices
integer vector,
struct_indexentries in the colortable that should be ignored- ignored_struct_names
vector of character strings,
struct_nameentries in the colortable that should be ignored. Can be combined withignored_struct_indices.