Translate names and indices of 3D image planes. The names only make sense if the data in the volume is in the default FreeSurfer conformed orientation.
Value
if plane is NULL, all available planes and their indices as a named list. If plane is an integer (a plane index), its name. If plane is an characters string (a plane name), its index.
See also
Other volume utility:
vol.boundary.box(),
vol.imagestack(),
vol.merge(),
vol.overlay.colors.from.activation(),
vol.slice()