Learn R Programming

fsbrain (version 1.0.0)

vol.sample.nearest: Sample a 3D volume at the given voxel coordinates using nearest neighbor interpolation.

Description

Sample a 3D volume at the given voxel coordinates using nearest neighbor interpolation.

Usage

vol.sample.nearest(volume_data, coords)

Value

numeric vector, one value per query point.

Arguments

volume_data

numeric 3D array, the volume data.

coords

numeric matrix with 3 columns and one row per query point, the 0-based voxel coordinates. Coordinates must be within the volume.