Sample a 3D volume at the given voxel coordinates using nearest neighbor interpolation.
vol.sample.nearest(volume_data, coords)numeric vector, one value per query point.
numeric 3D array, the volume data.
numeric matrix with 3 columns and one row per query point, the 0-based voxel coordinates. Coordinates must be within the volume.