| vol.sample.trilinear | R Documentation |
Sample a 3D volume at the given voxel coordinates using trilinear interpolation.
vol.sample.trilinear(volume_data, coords)
volume_data |
numeric 3D array, the volume data. |
coords |
numeric matrix with 3 columns and one row per query point, the 0-based voxel coordinates (column, row, slice). Coordinates must be within the volume, or an error will be raised. |
numeric vector, one interpolated value per query point.
Coordinates which are exactly on the last voxel result in the value of that voxel: the interpolation weights of the out-of-range upper neighbors become 0, and their index is clamped (which is safe because their weight is 0).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.