| vol.vol2surf.hemilist | R Documentation |
Project a volume onto the vertices of the given surfaces (internal workhorse).
vol.vol2surf.hemilist(
surfaces,
volume,
default_dir,
interpolation,
frame,
clamp,
check_fov,
affine = NULL,
vox2ras = "auto"
)
surfaces |
named list of vertex coordinate matrices, per hemisphere. |
volume |
the volume, as accepted by |
default_dir |
character string or NULL, the directory used to resolve volume names without extension. |
interpolation |
character string, see |
frame |
integer scalar, see |
clamp |
logical, whether to clamp query points outside the volume to the volume border. |
check_fov |
logical, whether to check (and warn about) vertices outside the volume. |
affine |
numeric 4x4 matrix or |
vox2ras |
character string, see |
named list of numeric vectors (one per hemisphere), with attribute 'outside' (named list of logical vectors or NULLs).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.