Project a volume onto the vertices of the given surfaces (internal workhorse).
vol.vol2surf.hemilist(
surfaces,
volume,
default_dir,
interpolation,
frame,
clamp,
check_fov,
affine = NULL,
vox2ras = "auto"
)named list of numeric vectors (one per hemisphere), with attribute 'outside' (named list of logical vectors or NULLs).
named list of vertex coordinate matrices, per hemisphere.
the volume, as accepted by vol.load.
character string or NULL, the directory used to resolve volume names without extension.
character string, see subject.vol2surf.
integer scalar, see subject.vol2surf.
logical, whether to clamp query points outside the volume to the volume border.
logical, whether to check (and warn about) vertices outside the volume.
numeric 4x4 matrix or NULL, used instead of the affine matrix from the volume header if given.
character string, see subject.vol2surf.