| vol.warn.outside | R Documentation |
Warn about surface vertices which are outside the volume.
vol.warn.outside(outside, num_verts, clamp)
outside |
named list of logical vectors, per hemisphere (or NULL entries if the check was disabled). |
num_verts |
named list of integer scalars, the number of vertices per hemisphere. |
clamp |
logical, whether outside vertices were clamped to the volume border instead of being set to NA. |
NULL, called for the side effect of emitting a warning.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.