Warn about surface vertices which are outside the volume.
vol.warn.outside(outside, num_verts, clamp)NULL, called for the side effect of emitting a warning.
named list of logical vectors, per hemisphere (or NULL entries if the check was disabled).
named list of integer scalars, the number of vertices per hemisphere.
logical, whether outside vertices were clamped to the volume border instead of being set to NA.