View source: R/volvis_shells.R
| volume.boxblur | R Documentation |
Applies a separable 3x3x3 box blur to a 3D array, once per requested pass. Voxels at the border of the volume are treated as if the volume were padded with its edge values.
volume.boxblur(volume, passes = 1L)
volume |
a 3D numerical array. |
passes |
positive integer, the number of blur passes. |
a 3D numerical array with identical dimensions.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.