View source: R/vis_volume_clusters.R
| volume.cluster.levels | R Documentation |
Computes the iso-levels at which the shells of the clusters are extracted: num_levels levels from the threshold up to the highest level, for each requested sign, ordered from the outermost (the threshold) to the innermost (the highest level) shell.
volume.cluster.levels(
volume,
threshold,
num_levels = 10L,
max_level = NULL,
max_level_quantile = 0.99,
positive = TRUE,
negative = TRUE
)
volume |
a 3D numerical array. |
threshold |
single positive number, the cluster threshold. |
num_levels |
positive integer, the number of levels per sign. |
max_level |
single positive number or |
max_level_quantile |
single value between 0 and 1, the quantile used to compute |
positive |
logical, whether to compute levels for the positive side. |
negative |
logical, whether to compute levels for the negative side. |
numerical vector of iso-levels, the negative ones (if any) first, each ordered from the outermost to the innermost shell.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.