View source: R/vis_volume_clusters.R
| volume.cluster.threshold | R Documentation |
Computes the threshold from the data if none was given, namely the requested quantile of the absolute values of the non-zero voxels.
volume.cluster.threshold(volume, threshold = NULL, threshold_quantile = 0.95)
volume |
a 3D numerical array. |
threshold |
single positive number or |
threshold_quantile |
single value between 0 and 1, the quantile used if |
single positive number, the threshold.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.