Computes the threshold from the data if none was given, namely the requested quantile of the absolute values of the non-zero voxels.
volume.cluster.threshold(volume, threshold = NULL, threshold_quantile = 0.95)single positive number, the threshold.
a 3D numerical array.
single positive number or NULL, the threshold given by the user.
single value between 0 and 1, the quantile used if threshold is NULL.