View source: R/vis_volume_clusters.R
| volume.clusters.colormap | R Documentation |
All shells of both signs share one colormap, so that the color of a shell is exactly the color that the colorbar shows for its iso-level. A symmetric range which covers all iso-levels is used unless the user requested a range via the 'range' entry of makecmap_options.
volume.clusters.colormap(makecmap_options, levels, max_abs = max(abs(levels)))
makecmap_options |
named list, the colormap options, see |
levels |
numerical vector of iso-levels. |
max_abs |
single positive number, the absolute value of the most extreme value that the colormap has to cover, i.e., half of the range of the colormap. Defaults to the highest absolute iso-level. |
named list with the entries 'map' (the squash colormap), 'colors' (a color per entry of levels), 'range' (the range of the colormap) and 'options' (makecmap_options, including the range, for the colorbar metadata of the meshes).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.