| volvis.lightbox | R Documentation |
A lightbox is a single image that holds a set of subimages, arranged in a grid. The images can have a small border or spacing between them. Consecutive subimages will be appear the same row of the grid.
If overlay_colors are given, the volume will be used as the background, and it will only be visible where overlay_colors has transparency.
volvis.lightbox(
volume,
slices = -5,
axis = 1L,
per_row = 5L,
per_col = NULL,
border_geometry = "5x5",
background_color = "#000000",
arrange_single_image = FALSE
)
volume |
3D array, can be numeric (gray-scale intensity values) or color strings. If numeric, the intensity values must be in range |
slices |
slice index definition. If a vector of integers, interpreted as slice indices. If a single negative interger |
axis |
positive integer in range 1L..3L, the axis to use. |
per_row |
positive integer, the number of subimages per row in the output image. If |
per_col |
positive integer, the number of subimages per column in the output image. If |
border_geometry |
string, a geometry string passed to |
background_color |
string, a valid ImageMagick color string such as "white" or "#000080". The color to use when extending images (e.g., when creating the border). Defaults to black. |
arrange_single_image |
logical, whether to apply the given arrangement (from parameters |
a magick image instance
You should, in most cases, not call this function directly. Use volvis.lb instead, which has a more intuitive interface.
volvis.lb
Other volume visualization:
vis.volume.on.surface(),
volvis.lb(),
volvis.lb.with.surface(),
volvis.slices.with.surface()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.