Reshape and write combined per-vertex data for a group to a single MGH file.
Source:R/fsdir_abstraction_group.R
write.group.morph.standard.sf.RdWrite morphometry data for a group into a single MGH or MGZ file. In neuroimaging, the first 3 dimensions in the resulting 4D volume file are space, and the 4th is the time/subject dimension.
Note
The file will contain no information on the subject identifiers. The data can be for one or both hemispheres. See group.morph.standard.sf to read the data back into R.